@media screen {
  a {
    b: c;
  }
}
@media screen and (color) {
  x {
    y: z;
  }
}

@media (color) {
  a {
    b: c;
  }
}
@media screen and (color) {
  x {
    y: z;
  }
}

@media (max-width: 300px) {
  a {
    b: c;
  }
}
@media (max-width: 300px) and (min-width: 200px) {
  x {
    y: z;
  }
}

@media screen {
  a {
    b: c;
  }
}

@media not screen {
  a {
    b: c;
  }
}

@media not screen {
  a {
    b: c;
  }
}
@media print {
  x {
    y: z;
  }
}

@media print {
  a {
    b: c;
  }
}
@media print {
  x {
    y: z;
  }
}

@media not screen {
  a {
    b: c;
  }
}

@media screen {
  a {
    b: c;
  }
}

@media only screen {
  a {
    b: c;
  }
}
@media only screen and (color) {
  x {
    y: z;
  }
}
