@supports (foo: bar) {
   div {
     foo: bar;
   }
 }
 @supports not (foo: bar) {
   div {
     bar: baz;
   }
 }
 @supports (foo: bar) and (bar: baz) {
   div {
     foo: bar;
     bar: baz;
   }
 }
 @supports (foo: bar) or (bar: baz) {
   div {
     bar: baz;
   }
 }
